@@ -4,6 +4,9 @@
 #' This is used to compare to the statistics from observations for each state.
 #'
 #' @param object an ldhmm object
+#' @param annualize logical, to annaulize the sd and mean to V (xsqrt(days.pa)x100) and R (xdays.pa). 
+#'                  Default is \code{FALSE}.
+#' @param days.pa a positive integer, specifying number of days per year, default is 252.
 #'
 #' @return a matrix of statistics for each state, size of states times 3
 #'
@@ -18,7 +21,9 @@
 #' @importFrom ecd ecld.kurtosis
 #' 
 ### <======================================================================>
-ldhmm.ld_stats <- function(object) {
+ldhmm.ld_stats <- function(object, 
+                           annualize=FALSE, 
+                           days.pa=252) {
     m <- object@m
     s <- matrix(NA, m, 3, byrow=TRUE)
     lds <- ldhmm.state_ld(object)
@@ -28,6 +33,13 @@ ldhmm.ld_stats <- function(object) {
         s[j,3] <- ecd::ecld.kurtosis(lds[[j]])
     }
     colnames(s) <- c("mean", "sd", "kurtosis")
+    
+    if (annualize) {
+        s[,1] <- s[,1] * days.pa
+        s[,2] <- s[,2] * sqrt(days.pa) * 100
+        colnames(s) <- c("R", "V", "kurtosis")
+    }
+    
     return(s)
 }
 ### <---------------------------------------------------------------------->
